.\" -*- nroff -*- generated from .Rd format
.BG
.FN points.geodata
.TL
Plot with Locations and Data Values
.DN
Produce a plot with data locations with options for points sizes,
patterns and colors being proportional to data values or to its quantiles.
.CS

points.geodata(geodata, coords=geodata$coords, data=geodata$data,
               data.col=1,
               pt.sizes=c("data.proportional","rank.proportional",
                          "quintiles", "quartiles",
                           "deciles", "equal"),
               cex.min, cex.max, pch.seq, col.seq,
               add.to.plot=FALSE,
               round.quantiles=FALSE, graph.pars=FALSE,
               xlab="Coords X", ylab="Coord Y", main = "", ...)

.RA
.AG geodata
a list containing elements `coords' and
`$data' described below. If not provided the arguments
`coords' and `data' must be provided instead.
.AG coords
an n x 2 matrix containing
coordinates of the n data locations in each row.
Defaults to `geodata$coords', if provided.
.AG data
a vector or matrix with data values.
If a matrix is provided each column is regarded as one variable or realization.
Defaults to `geodata$data', if provided.
.AG data.col
the number of the data column. Only used for the case when
`$data' is a matrix with several variables or simulations.
.AG pt.sizes
point sizes.
.AG cex.min
minimum values for the graphical parameter
`cex'. Defines the size of the point corresponding the minimum
data. Defaults to 0.5.
.AG cex.max
maximum values for the graphical parameter
`cex'. Defines the size of the point corresponding the maximum
data. If `pt.sizes = "equal"' it is used as the value for the
graphical parameter `cex'. Defaults to 1.5.
.AG pch.seq
numbers defining the graphical parameter `pch'.
.AG col.seq
number defining the colors in the graphical parameter `cor'.
.AG add.to.plot
if `TRUE' the points are added to an existing
plot, otherwise a new plot is created. Defaults to `FALSE'.
.AG round.quantiles
whether or not the values of the quantiles
should be rounded. Defaults to `FALSE'.
.AG graph.pars
if `TRUE' the graphics parameters are used are
returned. Defaults to `FALSE'.
.AG xlab
X label. Default to `Coords X'.
.AG ylab
Y label. Default to `Coords Y'.
.AG main
plot title. Default to none.
.AG \&...
further parameter for the functions `points'.
.RT
A plot is created or added on the current graphics device.
.IP "" 
By default no value is returned. However, if `graph.pars = TRUE'
a list with graphical parameters used to produce the plot is returned.
According to the input the list might contain the following components:
.IP "" 
.AG quantiles
the values of the quantiles used to divide the data
(if required).
.AG cex
the values of the graphics expansion parameter `cex'.
.AG col
the values of the graphics color parameter `col'.
.AG pch
the values of the graphics pattern parameter `pch'.
.SH REFERENCES
Further information about `geoR/geoS' can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`plot.geodata', `points',
`plot', `par'.
.EX
data(s100)  # only when using R (not necessary with S-PLUS)
#
points.geodata(s100, xlab="Coord X", ylab="Coord Y")

points.geodata(s100, xlab="Coord X", ylab="Coord Y",
               pt.size="rank.prop")

points.geodata(s100, xlab="Coord X", ylab="Coord Y", cex.max=1.7,
               col=gray(seq(1, 0.1, l=100)), pt.siz="equal")
               # function gray() works only for R

points.geodata(s100, pt.sizes="quintile", xlab="Coord X",
               ylab="Coord Y")

.KW spatial, dplot, aplot
.WR
